@@ -54,11 +54,11 @@ class patient_dataset(Dataset):
             for patient_id in all_unique_patient_ids:
                 for tp in all_unique_tp:
                     patient_dict = {}
-                    for i, (specific_otu, specific_mapping_table, patient_col_name), tp_col_name in enumerate(
+                    for i, (specific_otu, specific_mapping_table, patient_col_name, tp_col_name) in enumerate(
                             zip(otu_df, mapping_table, patient_id_name, time_name)):
                         current_microbiome_sample = specific_otu[
-                            specific_mapping_table[patient_col_name] == patient_id & specific_mapping_table[
-                                tp_col_name] == tp]
+                            (specific_mapping_table[patient_col_name] == patient_id) & (specific_mapping_table[
+                                                                                            tp_col_name] == tp)]
                         if i == 0 and current_microbiome_sample is not None:
                             patient_dict['FIELD0'] = current_microbiome_sample
                         elif i == 1 and current_microbiome_sample is not None:
